h5torch package
===============

.. autoclass:: h5torch.file.File     
   :members: register, append

.. autoclass:: h5torch.dataset.Dataset     
   :members:

.. autoclass:: h5torch.dataset.SliceDataset     
   :members: 

